mlbench_core.aggregation
------------------------

.. autoapimodule:: mlbench_core.aggregation
.. currentmodule:: mlbench_core.aggregation


pytorch
~~~~~~~

.. autoapimodule:: mlbench_core.aggregation.pytorch
.. currentmodule:: mlbench_core.aggregation.pytorch

Aggregation
+++++++++++

.. autoapimodule:: mlbench_core.aggregation.pytorch.aggregation
.. currentmodule:: mlbench_core.aggregation.pytorch.aggregation

.. autoapiclass:: Aggregation
    :members:
    :private-members:
    :undoc-members:

Centralized (Synchronous) aggregation
+++++++++++++++++++++++++++++++++++++

.. autoapimodule:: mlbench_core.aggregation.pytorch.centralized
.. currentmodule:: mlbench_core.aggregation.pytorch.centralized

All-Reduce
''''''''''

.. autoapiclass:: AllReduceAggregation
    :show-inheritance:
    :private-members:

All-Reduce Horovod
''''''''''''''''''

.. autoapiclass:: AllReduceAggregationHVD
    :show-inheritance:
    :private-members:

Sparsified Aggregation
''''''''''''''''''''''

.. autoapiclass:: SparsifiedAggregation
    :show-inheritance:
    :private-members:

Power Aggregation
'''''''''''''''''

.. autoapiclass:: PowerAggregation
    :show-inheritance:
    :private-members:

Decentralized (Asynchronous) aggregation
++++++++++++++++++++++++++++++++++++++++

.. autoapimodule:: mlbench_core.aggregation.pytorch.decentralized
.. currentmodule:: mlbench_core.aggregation.pytorch.decentralized

Decentralized Aggregation
'''''''''''''''''''''''''

.. autoapiclass:: DecentralizedAggregation
    :show-inheritance:
    :private-members:


